Package: epitools
Version: 0.5-10.1
Date: 2017-10-26
Title: Epidemiology Tools
Authors@R: c(person("Tomas J.", "Aragon", role = "aut",
        email = "aragon@berkeley.edu"), person("Michael P.",
        "Fay", role = "ctb", email = "mfay@niaid.nih.gov"),
        person("Daniel", "Wollschlaeger", role = "ctb", email =
        "dwoll@psychologie.uni-kiel.de"),
        person("Adam", "Omidpanah", role = c("cre", "ctb"), email =
        "adam.omidpanah@wsu.edu"))
Depends: R (>= 2.10)
Description: Tools for training and practicing epidemiologists including methods for two-way and multi-way contingency tables.
License: GPL (>= 2)
Packaged: 2020-03-22 09:25:51 UTC; hornik
Author: Tomas J. Aragon [aut],
  Michael P. Fay [ctb],
  Daniel Wollschlaeger [ctb],
  Adam Omidpanah [cre, ctb]
Maintainer: Adam Omidpanah <adam.omidpanah@wsu.edu>
Repository: CRAN
Date/Publication: 2020-03-22 09:46:12 UTC
NeedsCompilation: no
Built: R 4.6.0; ; 2026-04-26 13:03:54 UTC; unix
